"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const glob = require("glob");
const mkdirp = require("mkdirp");
const path = require("path");
const rimraf = require("rimraf");
const writeClientIndex_1 = require("./writeClientIndex");
const writeClientModels_1 = require("./writeClientModels");
const writeClientServices_1 = require("./writeClientServices");
const writeClientSettings_1 = require("./writeClientSettings");
/**
 * Write our OpenAPI client, using the given templates at the given output path.
 * @param client Client object with all the models, services, etc.
 * @param language The language that should be generated (Typescript or Javascript).
 * @param httpClient The selected httpClient (fetch or XHR).
 * @param templates Templates wrapper with all loaded Handlebars templates.
 * @param outputPath
 */
function writeClient(client, language, httpClient, templates, outputPath) {
    const outputPathCore = path.resolve(outputPath, 'core');
    const outputPathModels = path.resolve(outputPath, 'models');
    const outputPathServices = path.resolve(outputPath, 'services');
    // Clean output directory
    try {
        rimraf.sync(outputPath);
    }
    catch (e) {
        throw new Error(`Could not clean output directory`);
    }
    // Create new directories
    try {
        mkdirp.sync(outputPath);
        mkdirp.sync(outputPathCore);
        mkdirp.sync(outputPathModels);
        mkdirp.sync(outputPathServices);
    }
    catch (e) {
        throw new Error(`Could not create output directories`);
    }
    // Copy all support files
    const supportFiles = path.resolve(__dirname, `../../src/templates/${language}/`);
    const supportFilesList = glob.sync('**/*.{ts,js}', { cwd: supportFiles });
    supportFilesList.forEach(file => {
        fs.copyFileSync(path.resolve(supportFiles, file), // From input path
        path.resolve(outputPath, file) // To output path
        );
    });
    // Write the client files
    try {
        writeClientIndex_1.writeClientIndex(client, language, templates, outputPath);
        writeClientModels_1.writeClientModels(client.models, language, templates, outputPathModels);
        writeClientServices_1.writeClientServices(client.services, language, templates, outputPathServices);
        writeClientSettings_1.writeClientSettings(client, language, httpClient, templates, outputPathCore);
    }
    catch (e) {
        throw e;
    }
}
exports.writeClient = writeClient;
