"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const path = require("path");
const exportModel_1 = require("./exportModel");
const format_1 = require("./format");
const getFileName_1 = require("./getFileName");
/**
 * Generate Models using the Handlebar template and write to disk.
 * @param models Array of Models to write.
 * @param language The output language (Typescript or javascript).
 * @param templates The loaded handlebar templates.
 * @param outputPath
 */
function writeClientModels(models, language, templates, outputPath) {
    models.forEach(model => {
        const fileName = getFileName_1.getFileName(model.name, language);
        try {
            const templateData = exportModel_1.exportModel(model);
            const templateResult = templates.model(templateData);
            fs.writeFileSync(path.resolve(outputPath, fileName), format_1.format(templateResult));
        }
        catch (e) {
            throw new Error(`Could not write model: "${fileName}"`);
        }
    });
}
exports.writeClientModels = writeClientModels;
